/*
 * Copyright 2008 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.constretto.internal.converter;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import org.constretto.ValueConverter;
import org.constretto.exception.ConstrettoConversionException;

import java.lang.reflect.Type;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;

/**
 * @author <a href="mailto:tom.palmer@whiteonesugar.com">Tom Palmer</a>
 */
public class UriValueConverter implements ValueConverter<URI> {
    private final Type listType = new TypeToken<List<String>>() {}.getType();
    private final Gson gson = new Gson();

    public URI fromString(String value) throws ConstrettoConversionException {
        try {
            return new URI(value);
        } catch (URISyntaxException e) {
            throw new ConstrettoConversionException(value, URL.class, e.getMessage());
        }
    }

    public List<URI> fromStrings(String value) throws ConstrettoConversionException {
        List<URI> uris = new ArrayList<URI>();
        List<String> names = gson.fromJson(value, listType);
        for (String name : names) {
            uris.add(fromString(name));
        }
        return uris;
    }
}
